# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
from __future__ import unicode_literals

# from django.db import models
# from django.utils.translation import ugettext_lazy as _

# Create your models here.
